@@ -6,7 +6,7 @@ from extreme_parser.util import read_file
 
 def parse_number(s, first=True) -> typing.Union[None, int, float, list]:
     def to_number(number_str):
-        return float(number_str) if "." in s else int(number_str)
+        return float(number_str) if "." in number_str else int(number_str)
 
     numbers = re.findall(r"\d+\.\d+|\d+", s)
     if len(numbers) <= 0:
